import { ResourceTemplate } from "@modelcontextprotocol/sdk/server/mcp.js";
export function registerProblemResources(server, leetcodeService) {
    // Daily challenge resource
    server.resource("daily-challenge", "leetcode://daily-challenge", async (uri) => {
        try {
            const data = await leetcodeService.fetchDailyChallenge();
            return {
                contents: [{
                        uri: uri.href,
                        text: JSON.stringify(data, null, 2),
                        mimeType: "application/json"
                    }]
            };
        }
        catch (error) {
            const errorMessage = error instanceof Error ? error.message : String(error);
            throw new Error(`Failed to fetch daily challenge: ${errorMessage}`);
        }
    });
    // Problem details resource
    server.resource("problem-details", new ResourceTemplate("leetcode://problem/{titleSlug}", { list: undefined }), async (uri, variables) => {
        const titleSlug = variables.titleSlug;
        try {
            const data = await leetcodeService.fetchProblem(titleSlug);
            return {
                contents: [{
                        uri: uri.href,
                        text: JSON.stringify(data, null, 2),
                        mimeType: "application/json"
                    }]
            };
        }
        catch (error) {
            const errorMessage = error instanceof Error ? error.message : String(error);
            throw new Error(`Failed to fetch problem details: ${errorMessage}`);
        }
    });
    // Problems list resource
    server.resource("problems-list", new ResourceTemplate("leetcode://problems{?tags,difficulty,limit,skip}", { list: undefined }), async (uri, variables) => {
        const tags = variables.tags;
        const difficulty = variables.difficulty;
        const limit = variables.limit;
        const skip = variables.skip;
        try {
            const data = await leetcodeService.searchProblems(tags, difficulty, parseInt(limit || "20"), parseInt(skip || "0"));
            return {
                contents: [{
                        uri: uri.href,
                        text: JSON.stringify(data, null, 2),
                        mimeType: "application/json"
                    }]
            };
        }
        catch (error) {
            const errorMessage = error instanceof Error ? error.message : String(error);
            throw new Error(`Failed to fetch problems list: ${errorMessage}`);
        }
    });
}
//# sourceMappingURL=problem-resources.js.map