import { ResourceTemplate } from "@modelcontextprotocol/sdk/server/mcp.js";
export function registerUserResources(server, leetcodeService) {
    // User profile resource
    server.resource("user-profile", new ResourceTemplate("leetcode://user/{username}/profile", { list: undefined }), async (uri, variables) => {
        const username = variables.username;
        try {
            const data = await leetcodeService.fetchUserProfile(username);
            return {
                contents: [{
                        uri: uri.href,
                        text: JSON.stringify(data, null, 2),
                        mimeType: "application/json"
                    }]
            };
        }
        catch (error) {
            const errorMessage = error instanceof Error ? error.message : String(error);
            throw new Error(`Failed to fetch user profile: ${errorMessage}`);
        }
    });
    // User submissions resource
    server.resource("user-submissions", new ResourceTemplate("leetcode://user/{username}/submissions{?limit}", { list: undefined }), async (uri, variables) => {
        const username = variables.username;
        const limit = variables.limit;
        try {
            const data = await leetcodeService.fetchUserSubmissions(username, parseInt(limit || "20"));
            return {
                contents: [{
                        uri: uri.href,
                        text: JSON.stringify(data, null, 2),
                        mimeType: "application/json"
                    }]
            };
        }
        catch (error) {
            const errorMessage = error instanceof Error ? error.message : String(error);
            throw new Error(`Failed to fetch user submissions: ${errorMessage}`);
        }
    });
    // User contest ranking resource
    server.resource("user-contest-ranking", new ResourceTemplate("leetcode://user/{username}/contest-ranking", { list: undefined }), async (uri, variables) => {
        const username = variables.username;
        try {
            const data = await leetcodeService.fetchUserContestRanking(username);
            return {
                contents: [{
                        uri: uri.href,
                        text: JSON.stringify(data, null, 2),
                        mimeType: "application/json"
                    }]
            };
        }
        catch (error) {
            const errorMessage = error instanceof Error ? error.message : String(error);
            throw new Error(`Failed to fetch user contest ranking: ${errorMessage}`);
        }
    });
}
//# sourceMappingURL=user-resources.js.map